@@ -8,15 +8,15 @@ class Log( ):
         self.backlog = []
     def append( self, mesg ):
         mesg = '{:%Y-%m-%dT%H:%M:%SZ}'.format(datetime.utcnow()) + ' ' + mesg + '\n'
-        print mesg
+        print( mesg )
         if( self.logfile ):
             try:
                 fh = open( self.logfile, 'a' )
                 fh.write( mesg )
             except IOError as e:
-                print "\nERROR: Unable to append mesg to logfile"
-                print "\n\tLogfile: " + self.logfile
-                print "\n\t" + e.strerror
+                print( "\nERROR: Unable to append mesg to logfile" )
+                print( "\n\tLogfile: " + self.logfile )
+                print( "\n\t" + e.strerror )
         else: self.backlog.append( mesg );
     def setfile( self, filename ):
         try:
@@ -24,7 +24,7 @@ class Log( ):
             for mesg in self.backlog: fh.write( mesg );
             fh.close()
         except IOError as e:
-            print "\nError: " + e.strerror + ": " + filename
+            print( "\nError: " + e.strerror + ": " + filename )
             return
         self.backlog = []
-        self.logfile = filename
\ No newline at end of file
+        self.logfile = filename
